Frozen-Flask
============

.. image:: https://img.shields.io/pypi/v/Frozen-Flask.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/Frozen-Flask

Freezes a Flask application into a set of static files. The result can be hosted
without any server-side software other than a traditional web server.

See documentation: http://pythonhosted.org/Frozen-Flask/

Build Status
------------

.. image:: https://img.shields.io/travis/Frozen-Flask/Frozen-Flask.svg?maxAge=2592000
   :target: https://travis-ci.org/Frozen-Flask/Frozen-Flask

License
-------

Frozen-Flask is uses a BSD 3-clause license. See LICENSE_.

.. _LICENSE: LICENSE
